using Exam.Application.Interface.Exam;
using Exam.ExamManages;
using Exam.Infrastructure.Data.Entity;
using Exam.Insfrastructure.Service.Service;
using Exam.Share.ViewResponses.Sourceware;
using Hotline.Application.Exam.QueryExtensions.ExamManages;
using Hotline.Repository.SqlSugar;
using Hotline.Repository.SqlSugar.Exam.Interfaces.ExamManages;
using Hotline.Share.Dtos.ExamManages;
using Hotline.Share.Requests.Exam;
using Hotline.Share.Requests.Sourceware;
using Hotline.Share.ViewResponses.Exam;
using Mapster;
using System.ComponentModel;
using XF.Domain.Dependency;

namespace Hotline.Application.Exam.Service.ExamManages
{
    /// <summary>
    /// 考试标签服务
    /// </summary>
    [Description("考试标签服务")]
    public class ExamTagService : ApiService<ExamTag, ExamTagDto,HotlineDbContext>,IExamTagService, IScopeDependency
    {
        private readonly IExamTagRepository _repository;
        public ExamTagService(IExamTagRepository repository) : base(repository)
        {
            _repository = repository;
        }

        public async Task<ExamTagDto> GetAsync(EntityQueryRequest entityQueryRequest)
        {
            var entity = await _repository.GetAsync(entityQueryRequest.Id);

            return entity.Adapt<ExamTagDto>();
        }

        public async Task<(int, List<ExamTagViewResponse>)> GetListAsync(ExamTagRequest queryRequest)
        {
            var query = _repository.Queryable();

            var result = await query.Select(m => new ExamTagViewResponse { 
                				Name = m.Name,
								ParentId = m.ParentId,
								Id = m.Id,
				            }).ToListAsync();

            var total = await query.CountAsync();

            return (total,result);
        }

        public async Task<PageViewResponse<ExamTagViewResponse>> GetPagedListAsync(ExamTagRequest queryRequest)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// 获取树状
        /// </summary>
        /// <param name="sourcewareCategoryDto"></param>
        /// <returns></returns>
        /// <exception cref="NotImplementedException"></exception>
        public async Task<List<ExamTagViewResponse>> GetTreeAsync(ExamTagRequest examTagRequest)
        {
            var expression = examTagRequest.GetExpression();

            var sourcewareCategorys = await _repository.GetTreeAsync(expression);

            var sourcewareCategoryViewResponses = sourcewareCategorys.Select(m => new ExamTagViewResponse
            {
                Id = m.Id,
                Name = m.Name,
                ParentId = m.ParentId,
                SortIndex = m.SortIndex,
                Children = m.Children.Adapt<List<ExamTagViewResponse>>()
            }).ToList();


            return sourcewareCategoryViewResponses;
        }
    }
}


